@@ -1,55 +1,19 @@
-#' followers_get
-#'
-#' @description Returns follower ids of specified Twitter user.
-#'
-#' @param user Screen name or user id of target user.
-#' @param token OAuth token (1.0 or 2.0). By default
-#'   \code{token = NULL} fetches a non-exhausted token from
-#'   an environment variable.
-#' @param page Default \code{page = -1} specifies first page of json
-#'   results. Other pages specified via cursor values supplied by
-#'   Twitter API response object.
-#' @param stringify logical, indicating whether to return user ids
-#'   as strings (some ids are too long to be read as numeric).
-#'   Defaults to \code{TRUE}.
-#' @seealso \url{https://dev.twitter.com/overview/documentation}
-#'
-#' @return user ids
-followers_get <- function(user, token = NULL, page = "-1",
-                           stringify = TRUE) {
-
-  params <- list(
-    id_type = user,
-    count = 5000,
-    cursor = page,
-    stringify = stringify)
-
-  names(params)[1] <- .id_type(user)
-
-  url <- make_url(restapi = TRUE, "followers/ids", params)
-
-  if (is.null(token)) {
-    token <- get_tokens()
-    token <- fetch_tokens(token, "followers/ids")
-  }
-
-  resp <- TWIT(get = TRUE, url, token)
-
-  flw <- from_js(resp)
-
-  flw
-}
-
 #' get_followers
 #'
 #' @description Returns max followers per token
 #' @param user Screen name or user id of target user.
-#' @param token OAuth token (1.0 or 2.0). By default
-#'   \code{token = NULL} fetches a non-exhausted token from
-#'   an environment variable.
+#' @param n Number of followers to return. For max return, enter
+#'   \code{n = "all"} or \code{n = 75000} (max per token).
 #' @param page Default \code{page = -1} specifies first page of json
 #'   results. Other pages specified via cursor values supplied by
 #'   Twitter API response object.
+#' @param parse Logical, indicating whether to return parsed
+#'   vector or nested list (fromJSON) object. By default,
+#'   \code{parse = TRUE} saves you the time [and frustrations]
+#'   associated with disentangling the Twitter API return objects.
+#' @param token OAuth token (1.0 or 2.0). By default
+#'   \code{token = NULL} fetches a non-exhausted token from
+#'   an environment variable.
 #' @seealso \url{https://dev.twitter.com/overview/documentation}
 #' @examples
 #' \dontrun{
@@ -67,28 +31,42 @@ followers_get <- function(user, token = NULL, page = "-1",
 #'   followers using either multiple tokens or by waiting out
 #'   rate limits)
 #' @export
-get_followers <- function(user, token = NULL, page = "-1") {
+get_followers <- function(user, n = 75000, page = "-1", parse = TRUE,
+                          token = NULL) {
 
-  if (is.null(token)) {
-    token <- get_tokens()
-    token <- fetch_tokens(token, "followers/ids")
+  query <- "followers/ids"
+
+  if (n == "all") {
+    n <- 75000
   }
 
-  remaining <- rate_limit(token, "followers/ids")[, "remaining"]
+  stopifnot(is_n(n), is.atomic(user), is.atomic(page))
 
-  flw <- character()
-
-  for (i in seq_len(remaining)) {
-
-    flw_new <- followers_get(user, token, page)
-
-    flw <- append(flw, getElement(flw_new, "ids"))
-
-    page <- getElement(flw_new, "next_cursor_str")
-
-    if (length(page) == 0) break
-    if (page == 0) break
+  if (length(user) > 1) {
+    stop("can only return followers for one user at a time.", call. = FALSE)
   }
 
-  list(user_id = flw, page = page)
+  token <- check_token(token, query)
+
+  n.times <- rate_limit(token, query)[["remaining"]]
+
+  params <- list(
+    user_type = user,
+    count = 5000,
+    cursor = page,
+    stringify = TRUE)
+
+  names(params)[1] <- .id_type(user)
+
+  url <- make_url(
+    query = query,
+    param = params)
+
+  f <- scroller(url, n, n.times, token)
+
+  f <- f[!sapply(f, is.null)]
+
+  if (parse) f <- parse_fs(f, n)
+
+  f
 }
